@@ -2,7 +2,7 @@
 #define QT_FEATURE_webengine_embedded_build -1
 #define QT_FEATURE_webengine_arm_thumb -1
 #define QT_FEATURE_webengine_printing_and_pdf 1
-#define QT_FEATURE_webengine_kerberos -1
+#define QT_FEATURE_webengine_kerberos 1
 #define QT_FEATURE_webengine_noexecstack 1
 #define QT_FEATURE_webengine_ozone_x11 1
 #define QT_FEATURE_webengine_pepper_plugins 1
